#if PERL_VERSION == 10 && PERL_SUBVERSION == 0
#include "token_info-5.10.0.h"
#elif PERL_VERSION == 10 && PERL_SUBVERSION == 1
#include "token_info-5.10.0.h"
#elif PERL_VERSION == 10
#include "token_info-5.10.0.h"
#elif PERL_VERSION == 11 && PERL_SUBVERSION == 0
#include "token_info-5.11.0.h"
#elif PERL_VERSION == 11 && PERL_SUBVERSION == 1
#include "token_info-5.11.0.h"
#elif PERL_VERSION == 11 && PERL_SUBVERSION == 2
#include "token_info-5.11.2.h"
#elif PERL_VERSION == 11 && PERL_SUBVERSION == 3
#include "token_info-5.11.2.h"
#elif PERL_VERSION == 11 && PERL_SUBVERSION == 4
#include "token_info-5.11.4.h"
#elif PERL_VERSION == 11 && PERL_SUBVERSION == 5
#include "token_info-5.11.5.h"
#elif PERL_VERSION == 12 && PERL_SUBVERSION == 0
#include "token_info-5.12.0.h"
#elif PERL_VERSION == 12 && PERL_SUBVERSION == 1
#include "token_info-5.12.0.h"
#elif PERL_VERSION == 12 && PERL_SUBVERSION == 2
#include "token_info-5.12.0.h"
#elif PERL_VERSION == 12 && PERL_SUBVERSION == 3
#include "token_info-5.12.0.h"
#elif PERL_VERSION == 12 && PERL_SUBVERSION == 4
#include "token_info-5.12.0.h"
#elif PERL_VERSION == 12 && PERL_SUBVERSION == 5
#include "token_info-5.12.0.h"
#elif PERL_VERSION == 12
#include "token_info-5.12.0.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 0
#include "token_info-5.13.0.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 1
#include "token_info-5.13.0.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 2
#include "token_info-5.13.2.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 3
#include "token_info-5.13.2.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 4
#include "token_info-5.13.2.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 5
#include "token_info-5.13.5.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 6
#include "token_info-5.13.6.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 7
#include "token_info-5.13.7.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 8
#include "token_info-5.13.8.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 9
#include "token_info-5.13.8.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 10
#include "token_info-5.13.10.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 11
#include "token_info-5.13.10.h"
#elif PERL_VERSION == 14 && PERL_SUBVERSION == 0
#include "token_info-5.14.0.h"
#elif PERL_VERSION == 14 && PERL_SUBVERSION == 1
#include "token_info-5.14.0.h"
#elif PERL_VERSION == 14 && PERL_SUBVERSION == 2
#include "token_info-5.14.0.h"
#elif PERL_VERSION == 14 && PERL_SUBVERSION == 3
#include "token_info-5.14.0.h"
#elif PERL_VERSION == 14 && PERL_SUBVERSION == 4
#include "token_info-5.14.0.h"
#elif PERL_VERSION == 14
#include "token_info-5.14.0.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 0
#include "token_info-5.15.0.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 1
#include "token_info-5.15.0.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 2
#include "token_info-5.15.2.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 3
#include "token_info-5.15.2.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 4
#include "token_info-5.15.2.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 5
#include "token_info-5.15.2.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 6
#include "token_info-5.15.2.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 7
#include "token_info-5.15.7.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 8
#include "token_info-5.15.7.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 9
#include "token_info-5.15.7.h"
#elif PERL_VERSION == 16 && PERL_SUBVERSION == 0
#include "token_info-5.16.0.h"
#elif PERL_VERSION == 16 && PERL_SUBVERSION == 1
#include "token_info-5.16.0.h"
#elif PERL_VERSION == 16 && PERL_SUBVERSION == 2
#include "token_info-5.16.0.h"
#elif PERL_VERSION == 16 && PERL_SUBVERSION == 3
#include "token_info-5.16.0.h"
#elif PERL_VERSION == 16
#include "token_info-5.16.0.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 0
#include "token_info-5.17.0.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 1
#include "token_info-5.17.1.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 2
#include "token_info-5.17.2.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 3
#include "token_info-5.17.3.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 4
#include "token_info-5.17.4.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 5
#include "token_info-5.17.5.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 6
#include "token_info-5.17.6.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 7
#include "token_info-5.17.6.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 8
#include "token_info-5.17.6.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 9
#include "token_info-5.17.6.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 10
#include "token_info-5.17.10.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 11
#include "token_info-5.17.10.h"
#elif PERL_VERSION == 18 && PERL_SUBVERSION == 0
#include "token_info-5.18.0.h"
#elif PERL_VERSION == 18 && PERL_SUBVERSION == 1
#include "token_info-5.18.0.h"
#elif PERL_VERSION == 18 && PERL_SUBVERSION == 2
#include "token_info-5.18.0.h"
#elif PERL_VERSION == 18 && PERL_SUBVERSION == 3
#include "token_info-5.18.0.h"
#elif PERL_VERSION == 18 && PERL_SUBVERSION == 4
#include "token_info-5.18.0.h"
#elif PERL_VERSION == 18
#include "token_info-5.18.0.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 0
#include "token_info-5.19.0.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 1
#include "token_info-5.19.1.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 2
#include "token_info-5.19.1.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 3
#include "token_info-5.19.1.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 4
#include "token_info-5.19.1.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 5
#include "token_info-5.19.5.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 6
#include "token_info-5.19.5.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 7
#include "token_info-5.19.5.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 8
#include "token_info-5.19.8.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 9
#include "token_info-5.19.9.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 10
#include "token_info-5.19.9.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 11
#include "token_info-5.19.9.h"
#elif PERL_VERSION == 20 && PERL_SUBVERSION == 0
#include "token_info-5.20.0.h"
#elif PERL_VERSION == 20 && PERL_SUBVERSION == 1
#include "token_info-5.20.0.h"
#elif PERL_VERSION == 20 && PERL_SUBVERSION == 2
#include "token_info-5.20.0.h"
#elif PERL_VERSION == 20 && PERL_SUBVERSION == 3
#include "token_info-5.20.0.h"
#elif PERL_VERSION == 20
#include "token_info-5.20.0.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 0
#include "token_info-5.21.0.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 1
#include "token_info-5.21.1.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 2
#include "token_info-5.21.1.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 3
#include "token_info-5.21.1.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 4
#include "token_info-5.21.4.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 5
#include "token_info-5.21.4.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 6
#include "token_info-5.21.4.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 7
#include "token_info-5.21.4.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 8
#include "token_info-5.21.8.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 9
#include "token_info-5.21.9.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 10
#include "token_info-5.21.9.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 11
#include "token_info-5.21.9.h"
#elif PERL_VERSION == 22 && PERL_SUBVERSION == 0
#include "token_info-5.22.0.h"
#elif PERL_VERSION == 22 && PERL_SUBVERSION == 1
#include "token_info-5.22.0.h"
#elif PERL_VERSION == 22 && PERL_SUBVERSION == 2
#include "token_info-5.22.0.h"
#elif PERL_VERSION == 22 && PERL_SUBVERSION == 3
#include "token_info-5.22.0.h"
#elif PERL_VERSION == 22 && PERL_SUBVERSION == 4
#include "token_info-5.22.0.h"
#elif PERL_VERSION == 22
#include "token_info-5.22.0.h"
#elif PERL_VERSION == 23 && PERL_SUBVERSION == 0
#include "token_info-5.23.0.h"
#elif PERL_VERSION == 23 && PERL_SUBVERSION == 1
#include "token_info-5.23.0.h"
#elif PERL_VERSION == 23 && PERL_SUBVERSION == 2
#include "token_info-5.23.0.h"
#elif PERL_VERSION == 23 && PERL_SUBVERSION == 3
#include "token_info-5.23.0.h"
#elif PERL_VERSION == 23 && PERL_SUBVERSION == 4
#include "token_info-5.23.4.h"
#elif PERL_VERSION == 23 && PERL_SUBVERSION == 5
#include "token_info-5.23.4.h"
#elif PERL_VERSION == 23 && PERL_SUBVERSION == 6
#include "token_info-5.23.4.h"
#elif PERL_VERSION == 23 && PERL_SUBVERSION == 7
#include "token_info-5.23.4.h"
#elif PERL_VERSION == 23 && PERL_SUBVERSION == 8
#include "token_info-5.23.8.h"
#elif PERL_VERSION == 23 && PERL_SUBVERSION == 9
#include "token_info-5.23.8.h"
#elif PERL_VERSION == 24 && PERL_SUBVERSION == 0
#include "token_info-5.24.0.h"
#elif PERL_VERSION == 24 && PERL_SUBVERSION == 1
#include "token_info-5.24.0.h"
#elif PERL_VERSION == 24 && PERL_SUBVERSION == 2
#include "token_info-5.24.0.h"
#elif PERL_VERSION == 24 && PERL_SUBVERSION == 3
#include "token_info-5.24.0.h"
#elif PERL_VERSION == 24 && PERL_SUBVERSION == 4
#include "token_info-5.24.0.h"
#elif PERL_VERSION == 24
#include "token_info-5.24.0.h"
#elif PERL_VERSION == 25 && PERL_SUBVERSION == 0
#include "token_info-5.25.0.h"
#elif PERL_VERSION == 25 && PERL_SUBVERSION == 1
#include "token_info-5.25.1.h"
#elif PERL_VERSION == 25 && PERL_SUBVERSION == 2
#include "token_info-5.25.1.h"
#elif PERL_VERSION == 25 && PERL_SUBVERSION == 3
#include "token_info-5.25.3.h"
#elif PERL_VERSION == 25 && PERL_SUBVERSION == 4
#include "token_info-5.25.3.h"
#elif PERL_VERSION == 25 && PERL_SUBVERSION == 5
#include "token_info-5.25.5.h"
#elif PERL_VERSION == 25 && PERL_SUBVERSION == 6
#include "token_info-5.25.6.h"
#elif PERL_VERSION == 25 && PERL_SUBVERSION == 7
#include "token_info-5.25.6.h"
#elif PERL_VERSION == 25 && PERL_SUBVERSION == 8
#include "token_info-5.25.8.h"
#elif PERL_VERSION == 25 && PERL_SUBVERSION == 9
#include "token_info-5.25.8.h"
#elif PERL_VERSION == 25 && PERL_SUBVERSION == 10
#include "token_info-5.25.8.h"
#elif PERL_VERSION == 25 && PERL_SUBVERSION == 11
#include "token_info-5.25.8.h"
#elif PERL_VERSION == 25 && PERL_SUBVERSION == 12
#include "token_info-5.25.8.h"
#elif PERL_VERSION == 26 && PERL_SUBVERSION == 0
#include "token_info-5.26.0.h"
#elif PERL_VERSION == 26 && PERL_SUBVERSION == 1
#include "token_info-5.26.0.h"
#elif PERL_VERSION == 26 && PERL_SUBVERSION == 2
#include "token_info-5.26.0.h"
#elif PERL_VERSION == 26 && PERL_SUBVERSION == 3
#include "token_info-5.26.0.h"
#elif PERL_VERSION == 26
#include "token_info-5.26.0.h"
#elif PERL_VERSION == 27 && PERL_SUBVERSION == 0
#include "token_info-5.27.0.h"
#elif PERL_VERSION == 27 && PERL_SUBVERSION == 1
#include "token_info-5.27.0.h"
#elif PERL_VERSION == 27 && PERL_SUBVERSION == 2
#include "token_info-5.27.0.h"
#elif PERL_VERSION == 27 && PERL_SUBVERSION == 3
#include "token_info-5.27.0.h"
#elif PERL_VERSION == 27 && PERL_SUBVERSION == 4
#include "token_info-5.27.0.h"
#elif PERL_VERSION == 27 && PERL_SUBVERSION == 5
#include "token_info-5.27.0.h"
#elif PERL_VERSION == 27 && PERL_SUBVERSION == 6
#include "token_info-5.27.0.h"
#elif PERL_VERSION == 27 && PERL_SUBVERSION == 7
#include "token_info-5.27.7.h"
#elif PERL_VERSION == 27 && PERL_SUBVERSION == 8
#include "token_info-5.27.8.h"
#elif PERL_VERSION == 27 && PERL_SUBVERSION == 9
#include "token_info-5.27.8.h"
#elif PERL_VERSION == 27 && PERL_SUBVERSION == 10
#include "token_info-5.27.10.h"
#elif PERL_VERSION == 27 && PERL_SUBVERSION == 11
#include "token_info-5.27.10.h"
#elif PERL_VERSION == 28 && PERL_SUBVERSION == 0
#include "token_info-5.28.0.h"
#elif PERL_VERSION == 28 && PERL_SUBVERSION == 1
#include "token_info-5.28.0.h"
#elif PERL_VERSION == 28 && PERL_SUBVERSION == 2
#include "token_info-5.28.0.h"
#elif PERL_VERSION == 28 && PERL_SUBVERSION == 3
#include "token_info-5.28.0.h"
#elif PERL_VERSION == 28
#include "token_info-5.28.0.h"
#elif PERL_VERSION == 29 && PERL_SUBVERSION == 0
#include "token_info-5.29.0.h"
#elif PERL_VERSION == 29 && PERL_SUBVERSION == 1
#include "token_info-5.29.0.h"
#elif PERL_VERSION == 29 && PERL_SUBVERSION == 2
#include "token_info-5.29.0.h"
#elif PERL_VERSION == 29 && PERL_SUBVERSION == 3
#include "token_info-5.29.0.h"
#elif PERL_VERSION == 29 && PERL_SUBVERSION == 4
#include "token_info-5.29.0.h"
#elif PERL_VERSION == 29 && PERL_SUBVERSION == 5
#include "token_info-5.29.0.h"
#elif PERL_VERSION == 29 && PERL_SUBVERSION == 6
#include "token_info-5.29.0.h"
#elif PERL_VERSION == 29 && PERL_SUBVERSION == 7
#include "token_info-5.29.0.h"
#elif PERL_VERSION == 29 && PERL_SUBVERSION == 8
#include "token_info-5.29.0.h"
#elif PERL_VERSION == 29 && PERL_SUBVERSION == 9
#include "token_info-5.29.0.h"
#elif PERL_VERSION == 29 && PERL_SUBVERSION == 10
#include "token_info-5.29.10.h"
#elif PERL_VERSION == 30 && PERL_SUBVERSION == 0
#include "token_info-5.30.0.h"
#elif PERL_VERSION == 30 && PERL_SUBVERSION == 1
#include "token_info-5.30.0.h"
#elif PERL_VERSION == 30 && PERL_SUBVERSION == 2
#include "token_info-5.30.0.h"
#elif PERL_VERSION == 30 && PERL_SUBVERSION == 3
#include "token_info-5.30.0.h"
#elif PERL_VERSION == 30
#include "token_info-5.30.0.h"
#elif PERL_VERSION == 31 && PERL_SUBVERSION == 0
#include "token_info-5.31.0.h"
#elif PERL_VERSION == 31 && PERL_SUBVERSION == 1
#include "token_info-5.31.1.h"
#elif PERL_VERSION == 31 && PERL_SUBVERSION == 2
#include "token_info-5.31.2.h"
#elif PERL_VERSION == 31 && PERL_SUBVERSION == 3
#include "token_info-5.31.3.h"
#elif PERL_VERSION == 31 && PERL_SUBVERSION == 4
#include "token_info-5.31.3.h"
#elif PERL_VERSION == 31 && PERL_SUBVERSION == 5
#include "token_info-5.31.5.h"
#elif PERL_VERSION == 31 && PERL_SUBVERSION == 6
#include "token_info-5.31.5.h"
#elif PERL_VERSION == 31 && PERL_SUBVERSION == 7
#include "token_info-5.31.5.h"
#elif PERL_VERSION == 31 && PERL_SUBVERSION == 8
#include "token_info-5.31.5.h"
#elif PERL_VERSION == 31 && PERL_SUBVERSION == 9
#include "token_info-5.31.5.h"
#elif PERL_VERSION == 31 && PERL_SUBVERSION == 10
#include "token_info-5.31.10.h"
#elif PERL_VERSION == 31 && PERL_SUBVERSION == 11
#include "token_info-5.31.10.h"
#elif PERL_VERSION == 32 && PERL_SUBVERSION == 0
#include "token_info-5.32.0.h"
#elif PERL_VERSION == 32 && PERL_SUBVERSION == 1
#include "token_info-5.32.0.h"
#elif PERL_VERSION == 32
#include "token_info-5.32.0.h"
#elif PERL_VERSION == 33 && PERL_SUBVERSION == 0
#include "token_info-5.33.0.h"
#elif PERL_VERSION == 33 && PERL_SUBVERSION == 1
#include "token_info-5.33.0.h"
#elif PERL_VERSION == 33 && PERL_SUBVERSION == 2
#include "token_info-5.33.0.h"
#elif PERL_VERSION == 33 && PERL_SUBVERSION == 3
#include "token_info-5.33.0.h"
#elif PERL_VERSION == 33 && PERL_SUBVERSION == 4
#include "token_info-5.33.0.h"
#elif PERL_VERSION == 33 && PERL_SUBVERSION == 5
#include "token_info-5.33.5.h"
#elif PERL_VERSION == 33 && PERL_SUBVERSION == 6
#include "token_info-5.33.6.h"
#elif PERL_VERSION == 33 && PERL_SUBVERSION == 7
#include "token_info-5.33.7.h"
#elif PERL_VERSION == 33 && PERL_SUBVERSION == 8
#include "token_info-5.33.7.h"
#elif PERL_VERSION == 33 && PERL_SUBVERSION == 9
#include "token_info-5.33.7.h"
#elif PERL_VERSION == 34 && PERL_SUBVERSION == 0
#include "token_info-5.34.0.h"
#elif PERL_VERSION == 34
#include "token_info-5.34.0.h"
#elif PERL_VERSION == 35 && PERL_SUBVERSION == 0
#include "token_info-5.35.0.h"
#elif PERL_VERSION == 35 && PERL_SUBVERSION == 1
#include "token_info-5.35.1.h"
#elif PERL_VERSION > 35 || (PERL_VERSION == 35 && PERL_SUBVERSION > 1)
#include "token_info-latest.h"
#else
#error "No support for this perl version"
#endif
